@@ -13,29 +13,15 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 from designate.objects import base
-from designate.objects import fields
 
 
-@base.DesignateRegistry.register
-class Tenant(base.DesignateObject, base.DictObjectMixin):
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-
-    fields = {
-        'id': fields.AnyField(nullable=True),
-        'zone_count': fields.AnyField(nullable=True),
-        'zones': fields.AnyField(nullable=True)
+class Tenant(base.DictObjectMixin, base.DesignateObject):
+    FIELDS = {
+        'id': {},
+        'domain_count': {},
+        'domains': {}
     }
 
-    STRING_KEYS = [
-        'id'
-    ]
 
-
-@base.DesignateRegistry.register
 class TenantList(base.ListObjectMixin, base.DesignateObject):
     LIST_ITEM_TYPE = Tenant
-
-    fields = {
-        'objects': fields.ListOfObjectsField('Tenant'),
-    }
